"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useApi = exports.ApiContextProvider = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const axios_1 = __importDefault(require("axios"));
const config_context_1 = require("./config-context");
const ApiContext = (0, react_1.createContext)(null);
function toResult(axiosResponse) {
    if (axiosResponse.status >= 200 && axiosResponse.status < 300) {
        return {
            data: axiosResponse.data,
            hasError: false,
            status: axiosResponse.status,
            errorMessage: '',
            error: ''
        };
    }
    else {
        return {
            data: undefined,
            hasError: true,
            errorMessage: axiosResponse.statusText,
            status: axiosResponse.status,
            error: axiosResponse.statusText
        };
    }
}
function toResultErr(error) {
    var _a, _b;
    if (error.response) {
        let message = ((_a = error.response) === null || _a === void 0 ? void 0 : _a.statusText) || 'Bir sistem hatası gerçekleşti, lütfen daha sonra tekrar deneyiniz';
        return {
            data: undefined,
            error,
            errorMessage: message,
            hasError: true,
            status: (_b = error.response) === null || _b === void 0 ? void 0 : _b.status
        };
    }
    else {
        return {
            data: undefined,
            error: error,
            errorMessage: "Sistem hatası",
            hasError: true
        };
    }
}
const ApiContextProvider = ({ children }) => {
    var _a, _b;
    const configuration = (0, config_context_1.useConfiguration)();
    const baseUrl = ((_a = configuration.api) === null || _a === void 0 ? void 0 : _a.baseUrl) || '';
    const useToken = ((_b = configuration.api) === null || _b === void 0 ? void 0 : _b.useToken) || (() => '');
    const token = useToken();
    const axios = (0, react_1.useRef)(axios_1.default.create({ baseURL: `${baseUrl}/` }));
    const [authenticated, setAuthenticated] = (0, react_1.useState)(false);
    const get = (0, react_1.useCallback)((resource) => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const result = yield axios.current.get(resource);
            return toResult(result);
        }
        catch (err) {
            return toResultErr(err);
        }
    }), []);
    const post = (0, react_1.useCallback)((resource, data) => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const result = yield axios.current.post(resource, data);
            return toResult(result);
        }
        catch (err) {
            return toResultErr(err);
        }
    }), []);
    const put = (0, react_1.useCallback)((resource, data) => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const result = yield axios.current.put(resource, data);
            return toResult(result);
        }
        catch (err) {
            return toResultErr(err);
        }
    }), []);
    const deleteFunc = (0, react_1.useCallback)((resource) => __awaiter(void 0, void 0, void 0, function* () {
        try {
            const result = yield axios.current.delete(resource);
            return toResult(result);
        }
        catch (err) {
            return toResultErr(err);
        }
    }), []);
    const value = (0, react_1.useMemo)(() => ({
        authenticated,
        get,
        post,
        put,
        delete: deleteFunc
    }), [authenticated, get, post, put, deleteFunc]);
    (0, react_1.useEffect)(() => {
        axios.current.defaults.headers['Authorization'] = token ? 'Bearer ' + token : '';
        setAuthenticated(!!axios.current.defaults.headers['Authorization']);
    }, [token]);
    return ((0, jsx_runtime_1.jsx)(ApiContext.Provider, Object.assign({ value: value }, { children: children })));
};
exports.ApiContextProvider = ApiContextProvider;
const useApi = () => (0, react_1.useContext)(ApiContext);
exports.useApi = useApi;
