"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useUserContext = exports.UserContextProvider = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const hooks_1 = require("../hooks");
const STORAGE_KEY = 'USER_CONTEXT';
const defaultData = {
    isLoggedIn: false,
    username: '',
    displayName: '',
    token: '',
    data: null
};
const UserContextReact = (0, react_1.createContext)(defaultData);
const UserContextProvider = ({ children, useLocalStorage, projectName }) => {
    const storageKey = STORAGE_KEY + "_" + (projectName || 'wface');
    const storage = (0, hooks_1.useStorage)(useLocalStorage ? 'local' : 'session');
    const storageData = storage.get(storageKey);
    const [data, setData] = (0, react_1.useState)(storageData || defaultData);
    const handleChangeData = (0, react_1.useCallback)((newData) => {
        setData(prev => {
            const value = Object.assign(Object.assign({}, prev), newData);
            storage.set(storageKey, value);
            return value;
        });
    }, []);
    const login = (0, react_1.useCallback)((values) => {
        handleChangeData(Object.assign(Object.assign({}, values), { isLoggedIn: true }));
    }, [handleChangeData]);
    const logout = (0, react_1.useCallback)(() => handleChangeData(defaultData), [handleChangeData]);
    const value = (0, react_1.useMemo)(() => (Object.assign(Object.assign({}, data), { login,
        logout })), [data, login, logout]);
    return ((0, jsx_runtime_1.jsx)(UserContextReact.Provider, Object.assign({ value: value }, { children: children })));
};
exports.UserContextProvider = UserContextProvider;
const useUserContext = () => (0, react_1.useContext)(UserContextReact);
exports.useUserContext = useUserContext;
